==> aiobastion-0.0.2.tar.gz: aiobastion-0.0.2/aiobastion/config.py <==
# -*- coding: utf-8 -*-

import yaml


class Config:
    def __init__(self, configfile):
        with open(configfile, 'r') as config:
            document = yaml.safe_load(config)

        try:
            if document["Connection"] is None:
                self.username = None
                self.password = None
                self.authtype = "Cyberark"
                self.appid = None
            else:
                if "Username" in document["Connection"].keys():
                    self.username = document["Connection"]["Username"]
                else:
                    self.username = None
                if "Password" in document["Connection"].keys():
                    self.password = document["Connection"]["Password"]
                else:
                    self.password = None
                if "AppId" in document["Connection"].keys():
                    self.appid = document["Connection"]["AppId"]
                else:
                    self.appid = None
                if "Authtype" in document["Connection"].keys():
                    self.authtype = document["Connection"]["Authtype"]
                else:
                    self.authtype = "Cyberark"

            if "PVWA" in document:
                if "Host" in document["PVWA"].keys():
                    self.PVWA = document["PVWA"]["Host"]
                if "CA" in document["PVWA"].keys():
                    self.PVWA_CA = document["PVWA"]["CA"]
                else:
                    self.PVWA_CA = False
                if "timeout" in document["PVWA"].keys():
                    self.timeout = int(document["PVWA"]["timeout"])
                else:
                    self.timeout = 30
            if "AIM" in document:
                self.AIM = True
                if "Host" in document["AIM"].keys():
                    self.AIM_HOST = document["AIM"]["Host"]
                else:
                    self.AIM = False
                if "AppID" in document["AIM"].keys():
                    self.AIM_AppID = document["AIM"]["AppID"]
                else:
                    self.AIM = False
                if "Cert" in document["AIM"].keys():
                    self.AIM_Cert = document["AIM"]["Cert"]
                else:
                    self.AIM = False
                if "Key" in document["AIM"].keys():
                    self.AIM_Key = document["AIM"]["Key"]
                else:
                    self.AIM = False
                if "CA" in document["AIM"].keys():
                    self.AIM_CA = document["AIM"]["CA"]
                else:
                    self.AIM_CA = False
            else:
                self.AIM = None

            if "CPM" in document:
                self.CPM = document["CPM"]
            else:
                self.CPM = ""
            if "retention" in document:
                self.retention = int(document["retention"])
            else:
                self.retention = 30
            if "customIPField" in document:
                self.customIPField = document["customIPField"]
            else:
                self.customIPField = None
        except AttributeError as e:
            raise ValueError(f"Malformed configuration file : {str(e)}")

# No rights at all
DEFAULT_PERMISSIONS = {
        "UseAccounts": False,
        "RetrieveAccounts": False,
        "ListAccounts": False,
        "AddAccounts": False,
        "UpdateAccountContent": False,
        "UpdateAccountProperties": False,
        "InitiateCPMAccountManagementOperations": False,
        "SpecifyNextAccountContent": False,
        "RenameAccounts": False,
        "DeleteAccounts": False,
        "UnlockAccounts": False,
        "ManageSafe": False,
        "ManageSafeMembers": False,
        "BackupSafe": False,
        "ViewAuditLog": False,
        "ViewSafeMembers": False,
        "AccessWithoutConfirmation": False,
        "CreateFolders": False,
        "DeleteFolders": False,
        "MoveAccountsAndFolders": False
    }

# Can create object
PROV_PERMISSIONS = dict(DEFAULT_PERMISSIONS)
PROV_PERMISSIONS.update({
        "ListAccounts": True,
        "AddAccounts": True,
        "UpdateAccountContent": True,
        "UpdateAccountProperties": True,
        "InitiateCPMAccountManagementOperations": False,
        "RenameAccounts": True,
        "DeleteAccounts": True,
        "ManageSafe": True,
        "ManageSafeMembers": True,
        "ViewSafeMembers": True,
        "AccessWithoutConfirmation": True,
        "CreateFolders": True,
        "DeleteFolders": True,
        "MoveAccountsAndFolders": True
    })

# all to true
ADMIN_PERMISSIONS = {perm: True for perm in DEFAULT_PERMISSIONS}

# connect
USE_PERMISSIONS = dict(DEFAULT_PERMISSIONS)
USE_PERMISSIONS["UseAccounts"] = True
USE_PERMISSIONS["ListAccounts"] = True
# Connect does not necessarily require AccessWithoutConfirmation
# USE_PERMISSIONS["AccessWithoutConfirmation"] = True

# use + retrieve
SHOW_PERMISSIONS = dict(USE_PERMISSIONS)
SHOW_PERMISSIONS["RetrieveAccounts"] = True

# list accounts + audit part
AUDIT_PERMISSIONS = dict(DEFAULT_PERMISSIONS)
AUDIT_PERMISSIONS["ListAccounts"] = True
AUDIT_PERMISSIONS["ViewAuditLog"] = True
AUDIT_PERMISSIONS["ViewSafeMembers"] = True

# power user = SHOW + AUDIT
POWER_PERMISSIONS = dict(DEFAULT_PERMISSIONS)
POWER_PERMISSIONS.update({k: v for k, v in SHOW_PERMISSIONS.items() if v})
POWER_PERMISSIONS.update({k: v for k, v in AUDIT_PERMISSIONS.items() if v})


CPM_PERMISSIONS = {
        "UseAccounts": True,
        "RetrieveAccounts": True,
        "ListAccounts": True,
        "AddAccounts": True,
        "UpdateAccountContent": True,
        "UpdateAccountProperties": True,
        "InitiateCPMAccountManagementOperations": True,
        "SpecifyNextAccountContent": True,
        "RenameAccounts": True,
        "DeleteAccounts": True,
        "UnlockAccounts": True,
        "ManageSafe": False,
        "ManageSafeMembers": False,
        "BackupSafe": False,
        "ViewAuditLog": True,
        "ViewSafeMembers": False,
        "RequestsAuthorizationLevel1": False,
        "RequestsAuthorizationLevel2": False,
        "AccessWithoutConfirmation": False,
        "CreateFolders": True,
        "DeleteFolders": True,
        "MoveAccountsAndFolders": True
}

# v2 perm
V2_BASE = {
    "useAccounts": True,
    "retrieveAccounts": False,
    "listAccounts": True,
    "addAccounts": False,
    "updateAccountContent": False,
    "updateAccountProperties": False,
    "initiateCPMAccountManagementOperations": False,
    "specifyNextAccountContent": False,
    "renameAccounts": False,
    "deleteAccounts": False,
    "unlockAccounts": False,
    "manageSafe": False,
    "manageSafeMembers": False,
    "backupSafe": False,
    "viewAuditLog": False,
    "viewSafeMembers": False,
    "accessWithoutConfirmation": False,
    "createFolders": False,
    "deleteFolders": False,
    "moveAccountsAndFolders": False,
    "requestsAuthorizationLevel1": False,
    "requestsAuthorizationLevel2": False
}

V2_USE = {
    "useAccounts": True,
    "listAccounts": True,
}
V2_ADMIN = {"manageSafeMembers": True}
V2_CHANGE = {"updateAccountContent": True}
V2_SHOW = {"retrieveAccounts": True}
V2_AUDIT = {"viewAuditLog": True}

#
# # power user = SHOW + AUDIT
# V2_POWER = dict(V2_SHOW)
# V2_POWER.update({k: v for k, v in V2_AUDIT.items() if v})


def validate_ip(s):
    a = s.split('.')
    if len(a) != 4:
        return False
    for x in a:
        if not x.isdigit():
            return False
        i = int(x)
        if i < 0 or i > 255:
            return False
    return True


def permissions(profile: str) -> dict:
    if "admin" in profile.lower():
        return ADMIN_PERMISSIONS
    if "use" in profile.lower():
        return USE_PERMISSIONS
    if "show" in profile.lower():
        return SHOW_PERMISSIONS
    if "audit" in profile.lower():
        return SHOW_PERMISSIONS
    if "prov" in profile.lower():
        return PROV_PERMISSIONS
    if "power" in profile.lower():
        return POWER_PERMISSIONS
    if "cpm" in profile.lower():
        return CPM_PERMISSIONS
    else:
        # nothing !
        return DEFAULT_PERMISSIONS


def get_v2_profile(permission) -> str:
    perms = []
    if all(t for t in [permission[k] == v for k, v in V2_ADMIN.items()]):
        perms.append("Admin")
    if all(t for t in [permission[k] == v for k, v in V2_AUDIT.items()]):
        perms.append("Audit")
    if all(t for t in [permission[k] == v for k, v in V2_SHOW.items()]):
        perms.append("Show")
    if all(t for t in [permission[k] == v for k, v in V2_CHANGE.items()]):
        perms.append("Change")
    if all(t for t in [permission[k] == v for k, v in V2_USE.items()]):
        perms.append("Use")
    if len(perms) == 0:
        perms.append("Profil Inconnu")
    return " + ".join(perms)

==> aiobastion-0.0.6.tar.gz: aiobastion-0.0.6/aiobastion/config.py <==
# -*- coding: utf-8 -*-

import yaml


class Config:
    def __init__(self, configfile):
        with open(configfile, 'r') as config:
            document = yaml.safe_load(config)

        try:
            if "Connection" not in document or document["Connection"] is None:
                self.username = None
                self.password = None
                self.authtype = "Cyberark"
                self.appid = None
            else:
                if "Username" in document["Connection"].keys():
                    self.username = document["Connection"]["Username"]
                else:
                    self.username = None
                if "Password" in document["Connection"].keys():
                    self.password = document["Connection"]["Password"]
                else:
                    self.password = None
                if "AppId" in document["Connection"].keys():
                    self.appid = document["Connection"]["AppId"]
                else:
                    self.appid = None
                if "Authtype" in document["Connection"].keys():
                    self.authtype = document["Connection"]["Authtype"]
                else:
                    self.authtype = "Cyberark"

            if "PVWA" in document:
                if "Host" in document["PVWA"].keys():
                    self.PVWA = document["PVWA"]["Host"]
                if "CA" in document["PVWA"].keys():
                    self.PVWA_CA = document["PVWA"]["CA"]
                else:
                    self.PVWA_CA = False
                if "timeout" in document["PVWA"].keys():
                    self.timeout = int(document["PVWA"]["timeout"])
                else:
                    self.timeout = 30
                if "MaxTasks" in document["PVWA"].keys():
                    self.max_concurrent_tasks = int(document["PVWA"]["MaxTasks"])
                else:
                    self.max_concurrent_tasks = 10

            if "AIM" in document:
                self.AIM = True
                if "Host" in document["AIM"].keys():
                    self.AIM_HOST = document["AIM"]["Host"]
                else:
                    self.AIM = False
                if "AppID" in document["AIM"].keys():
                    self.AIM_AppID = document["AIM"]["AppID"]
                else:
                    self.AIM = False
                if "Cert" in document["AIM"].keys():
                    self.AIM_Cert = document["AIM"]["Cert"]
                else:
                    self.AIM = False
                if "Key" in document["AIM"].keys():
                    self.AIM_Key = document["AIM"]["Key"]
                else:
                    self.AIM = False
                if "CA" in document["AIM"].keys():
                    self.AIM_CA = document["AIM"]["CA"]
                else:
                    self.AIM_CA = False
            else:
                self.AIM = None

            if "CPM" in document:
                self.CPM = document["CPM"]
            else:
                self.CPM = ""
            if "retention" in document:
                self.retention = int(document["retention"])
            else:
                self.retention = 30
            if "customIPField" in document:
                self.customIPField = document["customIPField"]
            else:
                self.customIPField = None
        except AttributeError as e:
            raise ValueError(f"Malformed configuration file : {str(e)}")

# No rights at all
DEFAULT_PERMISSIONS = {
        "UseAccounts": False,
        "RetrieveAccounts": False,
        "ListAccounts": False,
        "AddAccounts": False,
        "UpdateAccountContent": False,
        "UpdateAccountProperties": False,
        "InitiateCPMAccountManagementOperations": False,
        "SpecifyNextAccountContent": False,
        "RenameAccounts": False,
        "DeleteAccounts": False,
        "UnlockAccounts": False,
        "ManageSafe": False,
        "ManageSafeMembers": False,
        "BackupSafe": False,
        "ViewAuditLog": False,
        "ViewSafeMembers": False,
        "AccessWithoutConfirmation": False,
        "CreateFolders": False,
        "DeleteFolders": False,
        "MoveAccountsAndFolders": False
    }

# Can create object
PROV_PERMISSIONS = dict(DEFAULT_PERMISSIONS)
PROV_PERMISSIONS.update({
        "ListAccounts": True,
        "AddAccounts": True,
        "UpdateAccountContent": True,
        "UpdateAccountProperties": True,
        "InitiateCPMAccountManagementOperations": True,
        "RenameAccounts": True,
        "DeleteAccounts": True,
        "ManageSafe": False,
        "ManageSafeMembers": False,
        "ViewSafeMembers": False,
        "AccessWithoutConfirmation": True,
        "CreateFolders": True,
        "DeleteFolders": True,
        "MoveAccountsAndFolders": True
    })

MANAGER_PERMISSIONS = dict(PROV_PERMISSIONS)
MANAGER_PERMISSIONS.update({
    "ManageSafe": True,
    "ManageSafeMembers": True,
    "ViewSafeMembers": True,
})

# all to true
ADMIN_PERMISSIONS = {perm: True for perm in DEFAULT_PERMISSIONS}

# connect
USE_PERMISSIONS = dict(DEFAULT_PERMISSIONS)
USE_PERMISSIONS["UseAccounts"] = True
USE_PERMISSIONS["ListAccounts"] = True
# Connect does not necessarily require AccessWithoutConfirmation
# USE_PERMISSIONS["AccessWithoutConfirmation"] = True

# use + retrieve
SHOW_PERMISSIONS = dict(USE_PERMISSIONS)
SHOW_PERMISSIONS["RetrieveAccounts"] = True

# list accounts + audit part
AUDIT_PERMISSIONS = dict(DEFAULT_PERMISSIONS)
AUDIT_PERMISSIONS["ListAccounts"] = True
AUDIT_PERMISSIONS["ViewAuditLog"] = True
AUDIT_PERMISSIONS["ViewSafeMembers"] = True

# power user = SHOW + AUDIT
POWER_PERMISSIONS = dict(DEFAULT_PERMISSIONS)
POWER_PERMISSIONS.update({k: v for k, v in SHOW_PERMISSIONS.items() if v})
POWER_PERMISSIONS.update({k: v for k, v in AUDIT_PERMISSIONS.items() if v})

CPM_PERMISSIONS = {
        "UseAccounts": True,
        "RetrieveAccounts": True,
        "ListAccounts": True,
        "AddAccounts": True,
        "UpdateAccountContent": True,
        "UpdateAccountProperties": True,
        "InitiateCPMAccountManagementOperations": True,
        "SpecifyNextAccountContent": True,
        "RenameAccounts": True,
        "DeleteAccounts": True,
        "UnlockAccounts": True,
        "ManageSafe": False,
        "ManageSafeMembers": False,
        "BackupSafe": False,
        "ViewAuditLog": True,
        "ViewSafeMembers": False,
        "RequestsAuthorizationLevel1": False,
        "RequestsAuthorizationLevel2": False,
        "AccessWithoutConfirmation": False,
        "CreateFolders": True,
        "DeleteFolders": True,
        "MoveAccountsAndFolders": True
}

# v2 perm
V2_BASE = {
    "useAccounts": True,
    "retrieveAccounts": False,
    "listAccounts": True,
    "addAccounts": False,
    "updateAccountContent": False,
    "updateAccountProperties": False,
    "initiateCPMAccountManagementOperations": False,
    "specifyNextAccountContent": False,
    "renameAccounts": False,
    "deleteAccounts": False,
    "unlockAccounts": False,
    "manageSafe": False,
    "manageSafeMembers": False,
    "backupSafe": False,
    "viewAuditLog": False,
    "viewSafeMembers": False,
    "accessWithoutConfirmation": False,
    "createFolders": False,
    "deleteFolders": False,
    "moveAccountsAndFolders": False,
    "requestsAuthorizationLevel1": False,
    "requestsAuthorizationLevel2": False
}

V2_USE = {
    "useAccounts": True,
    "listAccounts": True,
}
V2_ADMIN = {"manageSafeMembers": True}
V2_CHANGE = {"updateAccountContent": True}
V2_SHOW = {"retrieveAccounts": True}
V2_AUDIT = {"viewAuditLog": True}

#
# # power user = SHOW + AUDIT
# V2_POWER = dict(V2_SHOW)
# V2_POWER.update({k: v for k, v in V2_AUDIT.items() if v})


def validate_ip(s):
    a = s.split('.')
    if len(a) != 4:
        return False
    for x in a:
        if not x.isdigit():
            return False
        i = int(x)
        if i < 0 or i > 255:
            return False
    return True


def permissions(profile: str) -> dict:
    if "admin" in profile.lower():
        return ADMIN_PERMISSIONS
    if "use" in profile.lower():
        return USE_PERMISSIONS
    if "show" in profile.lower():
        return SHOW_PERMISSIONS
    if "audit" in profile.lower():
        return SHOW_PERMISSIONS
    if "prov" in profile.lower():
        return PROV_PERMISSIONS
    if "power" in profile.lower():
        return POWER_PERMISSIONS
    if "cpm" in profile.lower():
        return CPM_PERMISSIONS
    if "manager" in profile.lower():
        return MANAGER_PERMISSIONS
    else:
        # nothing !
        return DEFAULT_PERMISSIONS


def get_v2_profile(permission) -> str:
    perms = []
    if all(t for t in [permission[k] == v for k, v in V2_ADMIN.items()]):
        perms.append("Admin")
    if all(t for t in [permission[k] == v for k, v in V2_AUDIT.items()]):
        perms.append("Audit")
    if all(t for t in [permission[k] == v for k, v in V2_SHOW.items()]):
        perms.append("Show")
    if all(t for t in [permission[k] == v for k, v in V2_CHANGE.items()]):
        perms.append("Change")
    if all(t for t in [permission[k] == v for k, v in V2_USE.items()]):
        perms.append("Use")
    if len(perms) == 0:
        perms.append("Profil Inconnu")
    return " + ".join(perms)
